#include <asterisk/lock.h>
#include <asterisk/file.h>
#include <asterisk/logger.h>
#include <asterisk/channel.h>
#include <asterisk/pbx.h>
#include <asterisk/callerid.h>
#include <asterisk/module.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <stdlib.h>

static char *tdesc = "Simple Short number deffinition";

static char *app = "ShortNumber";

static char *synopsis = "Define a short number";

static char *descrip = 
"  ShortNumber(realnumber):  Replace the exten with the real number and same priority. Returns 0\n"
"if the extensions exist, or -1 if the user hangs up or the extension does not exist.\n";

STANDARD_LOCAL_USER;

LOCAL_USER_DECL;

static int shortnumber_exec(struct ast_channel *chan, void *data)
{
	int res=-1;
	struct localuser *u;

	if (!data) {
		ast_log(LOG_WARNING, "ShortNumber requires an argument (the real phone number)\n");
		return -1;
	}

    if(ast_isphonenumber((char *)data)){
	    LOCAL_USER_ADD(u);
        if (ast_exists_extension(chan, chan->context, (char *)data, chan->priority, chan->callerid) ) {

            chan->priority--;
            strncpy(chan->exten, (char*)data, 80);
            res = 0;
        }

	    LOCAL_USER_REMOVE(u);
    }
	return res;
}

int unload_module(void)
{
	STANDARD_HANGUP_LOCALUSERS;
	return ast_unregister_application(app);
}

int load_module(void)
{
	return ast_register_application(app, shortnumber_exec, synopsis, descrip);
}

char *description(void)
{
	return tdesc;
}

int usecount(void)
{
	int res;
	STANDARD_USECOUNT(res);
	return res;
}

char *key()
{
	return ASTERISK_GPL_KEY;
}


